from setuptools import setup, find_packages

setup(
    name='geoLibDPP',
    version='1.4',
    description='A module for DPP classes',
    author='Pavel Babrovich',
    author_email='251223@student.pwr.edu.pl',
    packages=find_packages()
)